@@ -1,12 +1,12 @@
 package Glib::Install::Files;
 
 $self = {
-          'inc' => '-I/usr/local/include/glib-2.0 -I/usr/local/lib/glib-2.0/include   -DGPERL_DISABLE_THREADSAFE  -I. ',
+          'inc' => ' -I. -I/usr/local/include/glib-2.0 -I/usr/local/lib/glib-2.0/include  -DGPERL_DISABLE_THREADSAFE ',
           'typemaps' => [
                           'typemap'
                         ],
           'deps' => [],
-          'libs' => '-L/usr/local/lib -lgobject-2.0 -lglib-2.0 -lintl -liconv  '
+          'libs' => '-L/usr/local/lib -lgobject-2.0 -lglib-2.0 -lintl -liconv '
         };
 
 
